@@ -299,18 +299,10 @@ SEXP transform(SEXP fromargs, SEXP toargs, SEXP npts, SEXP x, SEXP y, SEXP z) {
 	if (have_z) {
             SET_VECTOR_ELT(res, 2, NEW_NUMERIC(n));
             SET_VECTOR_ELT(res, 3, NEW_CHARACTER(1));
-	    SET_STRING_ELT(VECTOR_ELT(res, 3), 0, 
-		COPY_TO_USER_STRING(pj_get_def(fromPJ, 0)));
 	    SET_VECTOR_ELT(res, 4, NEW_CHARACTER(1));
-	    SET_STRING_ELT(VECTOR_ELT(res, 4), 0, 
-		COPY_TO_USER_STRING(pj_get_def(toPJ, 0)));
         } else {
             SET_VECTOR_ELT(res, 2, NEW_CHARACTER(1));
-	    SET_STRING_ELT(VECTOR_ELT(res, 2), 0, 
-		COPY_TO_USER_STRING(pj_get_def(fromPJ, 0)));
 	    SET_VECTOR_ELT(res, 3, NEW_CHARACTER(1));
-	    SET_STRING_ELT(VECTOR_ELT(res, 3), 0, 
-		COPY_TO_USER_STRING(pj_get_def(toPJ, 0)));
         }
 
         if (ob_tran != 0) {
@@ -342,6 +334,17 @@ SEXP transform(SEXP fromargs, SEXP toargs, SEXP npts, SEXP x, SEXP y, SEXP z) {
 	      }
             }
         }
+	if (have_z) {
+	    SET_STRING_ELT(VECTOR_ELT(res, 3), 0, 
+		COPY_TO_USER_STRING(pj_get_def(fromPJ, 0)));
+	    SET_STRING_ELT(VECTOR_ELT(res, 4), 0, 
+		COPY_TO_USER_STRING(pj_get_def(toPJ, 0)));
+        } else {
+	    SET_STRING_ELT(VECTOR_ELT(res, 2), 0, 
+		COPY_TO_USER_STRING(pj_get_def(fromPJ, 0)));
+	    SET_STRING_ELT(VECTOR_ELT(res, 3), 0, 
+		COPY_TO_USER_STRING(pj_get_def(toPJ, 0)));
+        }
 
         pj_free(fromPJ);
 	if ( pj_is_latlong(toPJ) || ob_tran == -1) {
@@ -379,7 +382,7 @@ SEXP transform(SEXP fromargs, SEXP toargs, SEXP npts, SEXP x, SEXP y, SEXP z) {
 	return(res);
 }
 
-SEXP checkCRSArgs(SEXP args, SEXP init_found) {
+SEXP checkCRSArgs(SEXP args) {
 	SEXP res;
 	projPJ pj;
         char cbuf[512], cbuf1[512], c;
@@ -388,14 +391,12 @@ SEXP checkCRSArgs(SEXP args, SEXP init_found) {
 	SET_VECTOR_ELT(res, 0, NEW_LOGICAL(1));
 	SET_VECTOR_ELT(res, 1, NEW_CHARACTER(1));
 	LOGICAL_POINTER(VECTOR_ELT(res, 0))[0] = FALSE;
-        if (LOGICAL_POINTER(init_found)[0] && PJ_VERSION == 490) {
-            pj = pj_init_plus("+init=epsg:4326");
-	//pj_set_errno(0);
-	}
-	if (!(pj = pj_init_plus(CHAR(STRING_ELT(args, 0))))) {
+        pj = pj_init_plus(CHAR(STRING_ELT(args, 0)));
+	if (!(pj)) {
 
 		SET_STRING_ELT(VECTOR_ELT(res, 1), 0, 
-			COPY_TO_USER_STRING(pj_strerrno(*pj_get_errno_ref())));
+			COPY_TO_USER_STRING(pj_strerrno(*pj_get_errno_ref()))
+                );
 		pj_free(pj);
 		UNPROTECT(1);
 		return(res);
